from __future__ import annotations
import json
from datetime import datetime
from dataclasses import dataclass, field
from tubeulator.utils.string_conv import to_camel_case
from pydantic import AliasGenerator, BaseModel, ConfigDict, PrivateAttr
from ..utils.paths import DtoEnum

class Object(BaseModel):
    """
    Autogenerated from AirQuality::System.Object
    """

    model_config = ConfigDict(
        alias_generator=AliasGenerator(validation_alias=to_camel_case),
    )

    _source_schema_name: str = PrivateAttr(default='AirQuality')
    _component_schema_name: str = PrivateAttr(default='System.Object')


ObjectModel = Object


class Deserialisers(DtoEnum):
    System__Object = Object